@@ -17,6 +17,9 @@ class ReturnStatus(Enum):
     IS_LOCKED = "IS_LOCKED"
     OBSTRUCTED = "OBSTRUCTED"
     OUT_OF_REACH = "OUT_OF_REACH"
+    NOT_AGENT = "NOT_AGENT"
+    AGENT_CURRENTLY_INTERACTING_WTIH_PERFORMER = \
+        "AGENT_CURRENTLY_INTERACTING_WTIH_PERFORMER"
     SUCCESSFUL = "SUCCESSFUL"
     SUCCESSFUL_WITH_INVALID_PARAMETERS = "SUCCESSFUL_WITH_INVALID_PARAMETERS"
     UNDEFINED = "UNDEFINED"
